pm4py.algo.discovery.minimum\_self\_distance.variants package
=============================================================

Submodules
----------

pm4py.algo.discovery.minimum\_self\_distance.variants.log module
----------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.minimum_self_distance.variants.log
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.minimum\_self\_distance.variants.pandas module
-------------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.minimum_self_distance.variants.pandas
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.minimum_self_distance.variants
   :members:
   :undoc-members:
   :show-inheritance:
